@@ -24,6 +24,7 @@ let need_more s = error s "not enough data"
 let bad_char i s =
   error s (Printf.sprintf "invalid character '%c' at %d" s.[i] i)
 
+let string_of_list f l = "[" ^ (List.map f l |> String.concat "; ") ^ "]"
 let ( >>= ) v f = match v with Ok v -> f v | Error _ as e -> e
 
 let assert_raises ~msg exn test_fn =
@@ -451,6 +452,95 @@ module Test_v4 = struct
         assert_raises ~msg:addr exn (fun () -> V4.Prefix.of_string_exn addr))
       bad_addrs
 
+  let test_hosts () =
+    let nets =
+      [
+        ("255.255.255.255/32", [ "255.255.255.255" ], false);
+        ("255.255.255.255/32", [], true);
+        ("255.255.255.254/31", [ "255.255.255.254"; "255.255.255.255" ], true);
+        ("255.255.255.254/31", [ "255.255.255.254"; "255.255.255.255" ], false);
+        ("255.255.255.252/30", [ "255.255.255.253"; "255.255.255.254" ], true);
+        ( "255.255.255.252/30",
+          [
+            "255.255.255.252";
+            "255.255.255.253";
+            "255.255.255.254";
+            "255.255.255.255";
+          ],
+          false );
+        ( "192.0.2.0/29",
+          [
+            "192.0.2.0";
+            "192.0.2.1";
+            "192.0.2.2";
+            "192.0.2.3";
+            "192.0.2.4";
+            "192.0.2.5";
+            "192.0.2.6";
+            "192.0.2.7";
+          ],
+          false );
+        ( "192.0.2.0/29",
+          [
+            "192.0.2.1";
+            "192.0.2.2";
+            "192.0.2.3";
+            "192.0.2.4";
+            "192.0.2.5";
+            "192.0.2.6";
+          ],
+          true );
+      ]
+    in
+    List.iter
+      (fun (net, hosts, usable_flag) ->
+        let hosts = List.map V4.of_string_exn hosts in
+        let hosts_list =
+          List.of_seq
+            (V4.Prefix.hosts ~usable:usable_flag (V4.Prefix.of_string_exn net))
+        in
+        let msg =
+          Printf.sprintf
+            "incorrect sequence of hosts for %s (usable_flag: %b): %s" net
+            usable_flag
+            (string_of_list V4.to_string hosts_list)
+        in
+        assert_equal ~msg hosts_list hosts)
+      nets
+
+  let test_subnets () =
+    let nets =
+      [
+        ("255.255.255.255/32", [], 24);
+        ("192.0.2.0/24", [], 23);
+        ("255.255.255.255/32", [ "255.255.255.255/32" ], 32);
+        ( "255.255.255.254/31",
+          [ "255.255.255.254/32"; "255.255.255.255/32" ],
+          32 );
+        ( "255.255.255.252/30",
+          [ "255.255.255.252/31"; "255.255.255.254/31" ],
+          31 );
+        ("192.0.2.0/29", [ "192.0.2.0/30"; "192.0.2.4/30" ], 30);
+        ("192.0.2.0/24", [ "192.0.2.0/25"; "192.0.2.128/25" ], 25);
+        ("192.0.2.0/24", [ "192.0.2.0/24" ], 24);
+        ("10.0.0.0/8", [ "10.0.0.0/9"; "10.128.0.0/9" ], 9);
+      ]
+    in
+    List.iter
+      (fun (net, subnets, sz) ->
+        let subnets = List.map V4.Prefix.of_string_exn subnets in
+        let subnets_list =
+          List.of_seq (V4.Prefix.subnets sz (V4.Prefix.of_string_exn net))
+        in
+        let msg =
+          Printf.sprintf
+            "incorrect sequence of subnets for %s (prefix length: %i): %s" net
+            sz
+            (string_of_list V4.Prefix.to_string subnets_list)
+        in
+        assert_equal ~msg subnets_list subnets)
+      nets
+
   let suite =
     "Test V4"
     >::: [
@@ -481,6 +571,8 @@ module Test_v4 = struct
            "prefix_first_last" >:: test_prefix_first_last;
            "reject_octal" >:: test_reject_octal;
            "reject_prefix_octal" >:: test_reject_prefix_octal;
+           "hosts" >:: test_hosts;
+           "subnets" >:: test_subnets;
          ]
 end
 
@@ -589,7 +681,9 @@ module Test_v6 = struct
       "\000\000\000\000\000\000\000\000\000\000\255\255\192\168\000\001"
     in
     let v6 = V6.of_octets_exn addr in
-    assert_equal ~msg:(String.escaped addr) V6.(to_octets v6) addr
+    assert_equal ~printer:String.escaped ~msg:(String.escaped addr)
+      V6.(to_octets v6)
+      addr
 
   let test_bytes_rt_bad () =
     let addrs =
@@ -920,6 +1014,97 @@ module Test_v6 = struct
     assert_equal ~msg:"last ::aaa0/128" (ip_of_string "::aaa0")
       (last @@ of_string_exn "::aaa0/128")
 
+  let test_hosts () =
+    let nets =
+      [
+        ("2001:db8:0:ffff::/128", [ "2001:db8:0:ffff::" ], false);
+        ("2001:db8:0:ffff::/128", [], true);
+        ( "2001:db8:0:ffff::/127",
+          [ "2001:db8:0:ffff::"; "2001:db8:0:ffff::1" ],
+          false );
+        ( "2001:db8:0:ffff::/127",
+          [ "2001:db8:0:ffff::"; "2001:db8:0:ffff::1" ],
+          true );
+        ( "2001:db8:0:ffff::/126",
+          [
+            "2001:db8:0:ffff::";
+            "2001:db8:0:ffff::1";
+            "2001:db8:0:ffff::2";
+            "2001:db8:0:ffff::3";
+          ],
+          false );
+        ( "2001:db8:0:ffff::/126",
+          [ "2001:db8:0:ffff::1"; "2001:db8:0:ffff::2"; "2001:db8:0:ffff::3" ],
+          true );
+      ]
+    in
+    List.iter
+      (fun (net, hosts, usable_flag) ->
+        let hosts = List.map V6.of_string_exn hosts in
+        let hosts_list =
+          List.of_seq
+            (V6.Prefix.hosts ~usable:usable_flag (V6.Prefix.of_string_exn net))
+        in
+        let msg =
+          Printf.sprintf
+            "incorrect sequence of hosts for %s (usable_flag: %b): %s" net
+            usable_flag
+            (string_of_list V6.to_string hosts_list)
+        in
+        assert_equal ~msg hosts_list hosts)
+      nets
+
+  let test_subnets () =
+    let nets =
+      [
+        ("2001:db8:0:ffff::/128", [], 127);
+        ("2001:db8:0:ffff::/64", [], 63);
+        ("2001:db8:0:ffff::/128", [ "2001:db8:0:ffff::/128" ], 128);
+        ( "2001:db8:0:ffff::/127",
+          [ "2001:db8:0:ffff::/128"; "2001:db8:0:ffff::1/128" ],
+          128 );
+        ("::/0", [ "::/1"; "8000::/1" ], 1);
+        ("::/0", [ "::/2"; "4000::/2"; "8000::/2"; "c000::/2" ], 2);
+        ( "2001:db8:0:ffff::/126",
+          [ "2001:db8:0:ffff::/127"; "2001:db8:0:ffff::2/127" ],
+          127 );
+        ( "2001:db8:0:fff0::/60",
+          [
+            "2001:db8:0:fff0::/64";
+            "2001:db8:0:fff1::/64";
+            "2001:db8:0:fff2::/64";
+            "2001:db8:0:fff3::/64";
+            "2001:db8:0:fff4::/64";
+            "2001:db8:0:fff5::/64";
+            "2001:db8:0:fff6::/64";
+            "2001:db8:0:fff7::/64";
+            "2001:db8:0:fff8::/64";
+            "2001:db8:0:fff9::/64";
+            "2001:db8:0:fffa::/64";
+            "2001:db8:0:fffb::/64";
+            "2001:db8:0:fffc::/64";
+            "2001:db8:0:fffd::/64";
+            "2001:db8:0:fffe::/64";
+            "2001:db8:0:ffff::/64";
+          ],
+          64 );
+      ]
+    in
+    List.iter
+      (fun (net, subnets, sz) ->
+        let subnets = List.map V6.Prefix.of_string_exn subnets in
+        let subnets_list =
+          List.of_seq (V6.Prefix.subnets sz (V6.Prefix.of_string_exn net))
+        in
+        let msg =
+          Printf.sprintf
+            "incorrect sequence of subnets for %s (prefix length: %i): %s" net
+            sz
+            (string_of_list V6.Prefix.to_string subnets_list)
+        in
+        assert_equal ~msg subnets_list subnets)
+      nets
+
   let suite =
     "Test V6"
     >::: [
@@ -947,6 +1132,8 @@ module Test_v6 = struct
            "link_address_of_mac" >:: test_link_address_of_mac;
            "succ_pred" >:: test_succ_pred;
            "first_last" >:: test_first_last;
+           "hosts" >:: test_hosts;
+           "subnets" >:: test_subnets;
          ]
 end
 
